@@ -1,6 +1,6 @@
 =head1 NAME
 
-Term::Graille - Terminal Graphics using Braille
+Term::Graille - Graphical Display in the terminal using UTF8 Braille characters
 
 =head1 SYNOPSIS
  
@@ -20,8 +20,6 @@ extras. The goal is to achieve performance and features. with built-in
 turtle-like graphics, line and curve drawing (Algorithm::Line::Bresenham),
 scrolling, border setting, and more in development.
 
-
-
 =begin html
 
 <img src="https://user-images.githubusercontent.com/34284663/177032294-55dfda02-c24d-45c8-92ab-8c07ad39df66.gif">
@@ -33,20 +31,20 @@ scrolling, border setting, and more in development.
 
 =cut
 
-
-
 package Term::Graille;
 
 use strict;use warnings;
-our $VERSION="0.03";
+our $VERSION="0.04";
 use utf8;
 use open ":std", ":encoding(UTF-8)";
 use lib "../";
+use base 'Exporter';
+our @EXPORT_OK = qw/colour paint printAt clearScreen border/;
 use Algorithm::Line::Bresenham 0.13;
 use Time::HiRes "sleep";
 
 
-=head2 C<my $canvas=Term::Graille->new(%params)>
+=head2 C<my $canvas=Term::Graille-E<gt>new(%params)>
 
 Creates a new canavas; params are
 C<width> The pixel width, required C<height> the pixel height, required,
@@ -59,7 +57,6 @@ Title colour (optional)
 =cut
 
 
-
 sub new{
     my ( $class, %params ) = @_;     #  params are width and height in pixels
     my $self={width=>$params{width},height=>$params{height}};
@@ -81,7 +78,7 @@ sub new{
 }
 
 
-=head2 C<$canvas->draw()> , C<$canvas->draw($row, $column)>  
+=head2 C<$canvas-E<gt>draw()> , C<$canvas-E<gt>draw($row, $column)>  
 
 Draws the canvas to the terminal window. Optional row and column
 parameters may be passed to position the displayed canvas.  If 
@@ -93,13 +90,13 @@ this is added to the top border
 sub draw{
 	my ($self,$top,$left)=@_;  # the location on the screen can be overridden by passing row coloum position
 	$top//=$self->{top};$left//=$self->{left};
-	Display::border($top-1,$left-1,$top+@{$self->{grid}}-1,$left+@{$self->{grid}->[0]},$self->{borderStyle},$self->{borderColour})
+	border($top-1,$left-1,$top+@{$self->{grid}}-1,$left+@{$self->{grid}->[0]},$self->{borderStyle},$self->{borderColour})
 	    if defined $self->{borderStyle};
-	Display::printAt($top-1,$left+3,Display::paint($self->{title},$self->{titleColour})) if defined $self->{title}; ;
-	Display::printAt($top,$left, [reverse @{$self->{grid}}]);
+	printAt($top-1,$left+3,paint($self->{title},$self->{titleColour})) if defined $self->{title}; ;
+	printAt($top,$left, [reverse @{$self->{grid}}]);
 }
 
-=head2 C<$canvas->as_string()>  
+=head2 C<$canvas-E<gt>as_string()>  
 
 Returns the string containing the canvas of utf8 braille symbols, rows
 being separated by newline.
@@ -113,7 +110,7 @@ sub as_string{
 	return $str;
 }
 
-=head2 C<$canvas->set($x,$y,$pixelValue)>  
+=head2 C<$canvas-E<gt>set($x,$y,$pixelValue)>  
 
 Sets a particular pixel on (default if C<$pixelValue> not sent) or off.
 
@@ -134,7 +131,7 @@ sub set{
 	   (chr( ord($self->{unsetPix}-> [$xOffset]->[$yOffset]) & ord($self->{grid}->[$chrY]->[$chrX])));
 }
 
-=head2 C<$canvas->set($x,$y)>  
+=head2 C<$canvas-E<gt>set($x,$y)>  
 
 Sets the pixel value at C<$x,$y> to blank 
 
@@ -154,7 +151,7 @@ sub charOffset{  # gets the character grid position and offset within that chara
 	
 }
 
-=head2 C<$canvas->pixel($x,$y)>  
+=head2 C<$canvas-E<gt>pixel($x,$y)>  
 
 Gets the pixel value at C<$x,$y>
 
@@ -172,7 +169,7 @@ sub pixel{ #get pixel value at coordinates
 	return $orOp == ord('⠀')?0:1;
 }
 
-=head2 C<$canvas->clear()>  
+=head2 C<$canvas-E<gt>clear()>  
 
 Re-initialises the canvas with blank braille characters
 
@@ -184,7 +181,7 @@ sub clear{
 
 # Pixel plotting primitives for shapes using Bresenham (Algorithm::Line::Bresenham)
 
-=head2 C<$canvas->line($x1,$y1,$x2,$y2,$value)>  
+=head2 C<$canvas-E<gt>line($x1,$y1,$x2,$y2,$value)>  
 
 Uses Algorithm::Line::Bresenham to draw a line from C<$x1,$y1> to C<$x2,$y2>.
 The optional value C<$value> sets or unsets the pixels
@@ -199,7 +196,7 @@ sub line{
 }
 
 
-=head2 C<$canvas->circle($x1,$y1,$radius,$value)>  
+=head2 C<$canvas-E<gt>circle($x1,$y1,$radius,$value)>  
 
 Uses Algorithm::Line::Bresenham to draw a circle centered at C<$x1,$y1>
 with radius C<$radius> to C<$x2,$y2>.
@@ -215,7 +212,7 @@ sub circle{
 }
 
 
-=head2 C<$canvas->ellipse_rect($x1,$y1,$x2,$y2,$value)>    
+=head2 C<$canvas-E<gt>ellipse_rect($x1,$y1,$x2,$y2,$value)>    
 
 Uses Algorithm::Line::Bresenham to draw a rectangular ellipse,  (an 
 ellipse bounded by a rectangle defined by C<$x1,$y1,$x2,$y2>).
@@ -230,7 +227,7 @@ sub ellipse_rect{
 	$self->set(@$_,$value) foreach (@points);
 }
 
-=head2 C<$canvas->quad_bezier($x1,$y1,$x2,$y2,$x3,$y3,$value)>    
+=head2 C<$canvas-E<gt>quad_bezier($x1,$y1,$x2,$y2,$x3,$y3,$value)>    
 
 Uses Algorithm::Line::Bresenham to draw a quadratic bezier, defined by
 end points C<$x1,$y1,$x3,$y3>) and control point C<$x2,$y2>.
@@ -246,7 +243,7 @@ sub quad_bezier{
 	$self->set(@$_,$value) foreach (@points);
 }
 
-=head2 C<$canvas->polyline($x1,$y1,....,$xn,$yn,$value)>    
+=head2 C<$canvas-E<gt>polyline($x1,$y1,....,$xn,$yn,$value)>    
 
 Uses Algorithm::Line::Bresenham to draw a poly line, form a
 sequences of points.
@@ -268,7 +265,7 @@ sub degToRad{
 	return 3.14159267*$_[0]/180 ;
 }
 
-=head2 C<$canvas->scroll($direction,$wrap)>    
+=head2 C<$canvas-E<gt>scroll($direction,$wrap)>    
 
 Scrolls in C<$direction>.  $direction may be
 "l", "left", "r","right", "u","up","d", "down". 
@@ -321,23 +318,23 @@ sub scroll{
 }
 
 
-=head2 C<$canvas->logo($script)>    
+=head2 C<$canvas-E<gt>logo($script)>    
 
 Interface to Graille's built in Turtle interpreter.
 A string is taken and split by senicolons or newlines into intsructions.
 The instructions are trimmed, and split by the first space character into 
 command and parameters. Very simple in other words.
 
-C<fd distance>  pen moves forward a certain distance. 
-C<lt angle> C<rt angle> turns left or right. 
-C<bk distance> pen moves back a certain distance
-C<pu> C<pd> Pen is up or down, up means no drawing takes place,
+C<"fd distance">  pen moves forward a certain distance.  
+C<"lt angle">, C<"rt angle"> turns left or right.  
+C<"bk distance"> pen moves back a certain distance. 
+C<"pu">, C<"pd"> Pen is up or down, up means no drawing takes place,
 and down means the turtle draws as it moves.
-C<dir> set teh direction at a specific angle in dgrees, 
+C<"dir"> set the direction at a specific angle in dgrees, 
 with 0 being directly left.
-C<mv>moves pen to specific coordinates without drawing
-C<ce> centers the turtle in the middle of a canvas
-C<sp> allows animated drawing by specifiying the the number 
+C<"mv">moves pen to specific coordinates without drawing. 
+C<"ce"> centers the turtle in the middle of a canvas
+C<"sp"> allows animated drawing by specifiying the the number 
 of centiseconds between instructions
 
 =cut
@@ -411,9 +408,6 @@ sub logo{
 	}
 }
 
-
-package Display;
-
 our %borders=(
   simple=>{tl=>"+", t=>"-", tr=>"+", l=>"|", r=>"|", bl=>"+", b=>"-", br=>"+",},
   double=>{tl=>"╔", t=>"═", tr=>"╗", l=>"║", r=>"║", bl=>"╚", b=>"═", br=>"╝",},
@@ -473,11 +467,12 @@ Saif Ahmed
 
 =head1 LICENSE
 
-Artististic, Same as Perl
+Artistic
 
 =head1 INSTALLATION
 
 
+
 Manual install:
 
     $ perl Makefile.PL
